@@ -15,7 +15,7 @@ admin.site.register(PluginType, PluginTypeAdmin)
 
 
 class BlockPathAdmin(admin.ModelAdmin):
-    pass
+    search_fields = ('path', )
 
 admin.site.register(BlockPath, BlockPathAdmin)
 
@@ -23,5 +23,6 @@ admin.site.register(BlockPath, BlockPathAdmin)
 class BlockAdmin(admin.ModelAdmin):
     list_display = ('pk', 'area', 'path', 'position', 'plugin_type')
     list_filter = ('area', )
-
+    search_fields = ('path__path', 'plugin_type__name' )
+    
 admin.site.register(Block, BlockAdmin)
